Struct rayon::par_iter::len::ParallelLen [] [src]

pub struct ParallelLen {
    pub maximal_len: usize,
    pub cost: f64,
    pub sparse: bool,
}

Fields

maximal_len: usize

Maximal number of elements that we will write

cost: f64

An estimate of the "cost" of this operation. This is a kind of abstract concept you can use to influence how fine-grained the threads are.

TODO: refine this metric.

sparse: bool

If true, all elements will be written. If false, some may not. For example, sparse will be false if there is a filter. When doing a collect, sparse iterators require a compression step.

Methods

impl ParallelLen
[src]

fn left_cost(&self, mid: usize) -> ParallelLen

fn right_cost(&self, mid: usize) -> ParallelLen